%bcond_with bootstrap

Summary:        Lightweight dependency injection framework for Java 5 and above
Name:           google-guice
Version:        4.2.3
Release:        12%{?dist}
License:        ASL 2.0
URL:            https://github.com/google/guice
Source0:        https://github.com/google/guice/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  maven-local
%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(com.google.guava:guava)
BuildRequires:  mvn(javax.inject:javax.inject)
BuildRequires:  mvn(javax.servlet:servlet-api)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-remote-resources-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.sonatype.plugins:munge-maven-plugin)
%endif
%if %{without bootstrap}
BuildRequires:  mvn(org.apache:apache-jar-resource-bundle)
%endif

BuildArch:      noarch

%description
Put simply, Guice alleviates the need for factories and the use of new
in your Java code. Think of Guice's @Inject as the new new. You will
still need to write factories in some cases, but your code will not
depend directly on them. Your code will be easier to change, unit test
and reuse in other contexts.
Guice embraces Java's type safe nature, especially when it comes to
features introduced in Java 5 such as generics and annotations. You
might think of Guice as filling in missing features for core
Java. Ideally, the language itself would provide most of the same
features, but until such a language comes along, we have Guice.
Guice helps you design better APIs, and the Guice API itself sets a
good example. Guice is not a kitchen sink. We justify each feature
with at least three use cases. When in doubt, we leave it out. We
build general functionality which enables you to extend Guice rather
than adding every feature to the core framework.

%package -n guice-parent
Summary:        Guice parent POM

%description -n guice-parent
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides parent POM for Guice modules.

%package -n guice-assistedinject
Summary:        AssistedInject extension module for Guice

%description -n guice-assistedinject
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides AssistedInject module for Guice.

%if %{without bootstrap}
%package -n guice-extensions
Summary:        Extensions for Guice

%description -n guice-extensions
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides extensions POM for Guice.
%endif

%package -n guice-grapher
Summary:        Grapher extension module for Guice

%description -n guice-grapher
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides Grapher module for Guice.

%package -n guice-jmx
Summary:        JMX extension module for Guice

%description -n guice-jmx
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides JMX module for Guice.

%package -n guice-jndi
Summary:        JNDI extension module for Guice

%description -n guice-jndi
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides JNDI module for Guice.

%package -n guice-multibindings
Summary:        MultiBindings extension module for Guice

%description -n guice-multibindings
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides MultiBindings module for Guice.

%package -n guice-servlet
Summary:        Servlet extension module for Guice

%description -n guice-servlet
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides Servlet module for Guice.

%package -n guice-throwingproviders
Summary:        ThrowingProviders extension module for Guice

%description -n guice-throwingproviders
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides ThrowingProviders module for Guice.

%package -n guice-bom
Summary:        Bill of Materials for Guice

%description -n guice-bom
Guice is a lightweight dependency injection framework for Java 5
and above. This package provides Bill of Materials module for Guice.

%{?javadoc_package}

%prep
%autosetup -n guice-%{version}

%pom_disable_module struts2 extensions
%pom_disable_module dagger-adapter extensions
%pom_xpath_remove "pom:profile[pom:id='guice.with.jarjar']" core
%pom_xpath_set "pom:instructions/pom:Import-Package" \
  "!com.google.inject.*,*" core
%pom_remove_plugin :animal-sniffer-maven-plugin core
%pom_remove_plugin :animal-sniffer-maven-plugin extensions
%pom_remove_plugin :maven-gpg-plugin
%pom_remove_plugin -r :maven-javadoc-plugin
%pom_remove_dep :guava-testlib extensions
%pom_xpath_remove "pom:dependency[pom:classifier='tests']" extensions
%pom_remove_parent
%pom_set_parent com.google.inject:guice-parent:%{version} jdk8-tests
%pom_disable_module persist extensions
%pom_disable_module spring extensions
%pom_disable_module jdk8-tests
%pom_xpath_set "pom:build/pom:pluginManagement/pom:plugins/pom:plugin[pom:artifactId='maven-compiler-plugin']/pom:configuration/pom:source" "1.8"
%pom_xpath_set "pom:build/pom:pluginManagement/pom:plugins/pom:plugin[pom:artifactId='maven-compiler-plugin']/pom:configuration/pom:target" "1.8"
%pom_disable_module testlib extensions
%pom_remove_dep :aopalliance core
%pom_remove_dep :asm core
%pom_remove_dep :cglib core
%pom_xpath_remove "pom:plugin[pom:artifactId='maven-jar-plugin']/pom:configuration"
%pom_xpath_remove "pom:plugin[pom:artifactId='maven-jar-plugin']/pom:executions"
%pom_xpath_set "pom:plugin[pom:artifactId='munge-maven-plugin']/pom:executions/pom:execution/pom:phase" generate-sources core
%pom_xpath_set "pom:plugin[pom:artifactId='munge-maven-plugin']/pom:executions/pom:execution/pom:goals/pom:goal" munge core
%pom_xpath_inject "pom:dependency[pom:artifactId='guice']" "<scope>provided</scope>" extensions

%build
%mvn_alias "com.google.inject.extensions:" "org.sonatype.sisu.inject:"
%mvn_package :::no_aop: guice
%mvn_package :guice:jar:{}: __noinstall
%mvn_file  ":guice-{*}"  guice/guice-@1
%mvn_file  ":guice" guice/%{name} %{name}
%mvn_alias ":guice" "org.sonatype.sisu:sisu-guice"
%mvn_build -f -s

%install
%mvn_install
%if %{with bootstrap}
rm %{buildroot}/usr/share/maven-metadata/google-guice-extensions-parent.xml
rm %{buildroot}/usr/share/maven-poms/google-guice/extensions-parent.pom
%endif

%files -n %{name} -f .mfiles-guice

%files -n guice-parent -f .mfiles-guice-parent
%license COPYING

%files -n guice-assistedinject -f .mfiles-guice-assistedinject

%if %{without bootstrap}
%files -n guice-extensions -f .mfiles-extensions-parent
%endif

%files -n guice-grapher -f .mfiles-guice-grapher

%files -n guice-jmx -f .mfiles-guice-jmx

%files -n guice-jndi -f .mfiles-guice-jndi

%files -n guice-multibindings -f .mfiles-guice-multibindings

%files -n guice-servlet -f .mfiles-guice-servlet

%files -n guice-throwingproviders -f .mfiles-guice-throwingproviders

%files -n guice-bom -f .mfiles-guice-bom

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.2.3-12
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.2.3-11
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.2.3-10
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 20 2023 Xiaojie Chen <jackxjchen@tencent.com> - 4.2.3-9
- Disable bootstrap

* Thu Apr 13 2023 Xiaojie Chen <jackxjchen@tencent.com> - 4.2.3-8
- Remove unused script

* Wed Apr 12 2023 Xiaojie Chen <jackxjchen@tencent.com> - 4.2.3-7
- Rewritten spec for maven 3.8.6

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.2.3-6
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 22 2023 Zhao Zhen <jeremiazhao@tencent.com> - 4.2.3-5
- small fix

* Wed Mar 22 2023 Zhao Zhen <jeremiazhao@tencent.com> - 4.2.3-4
- recovery guice-extensions subpackage

* Wed Mar 22 2023 Zhao Zhen <jeremiazhao@tencent.com> - 4.2.3-3
- rebuild for opencloudos

* Tue Dec 20 2022 Zhao Zhen <jeremiazhao@tencent.com> - 4.2.3-2
- using maven-local instead of maven-local-openjdk8

* Tue Dec 20 2022 Zhao Zhen <jeremiazhao@tencent.com> - 4.2.3-1
- initial
